Open a DDI assessment report template
ddi_report.RdCrate a new DDI report template as R markdown file in the working directory, and open it. The new report contains examplinib data for reference. Requires RStudio for the editor; otherwise the file is written and the path is returned.